@@ -1,4 +1,17 @@
 """Network instance module."""
+#   Copyright 2022 Orange, Deutsche Telekom AG
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 
 from onapsdk.so.deletion import NetworkDeletionRequest
 
@@ -132,6 +145,16 @@ class NetworkInstance(Instance):  # pylint: disable=too-many-instance-attributes
                 f"is_external_network={self.is_external_network}, "
                 f"orchestration_status={self.orchestration_status})")
 
+    @classmethod
+    def get_all_url(cls) -> str:  # pylint: disable=arguments-differ
+        """Return url to get all networks.
+
+        Returns:
+            str: Url to get all networks
+
+        """
+        return f"{cls.base_url}{cls.api_version}/network/l3-networks/"
+
     @property
     def url(self) -> str:
         """Network instance url.
